@@ -21,7 +21,9 @@ func (e *Executor) areTaskPreconditionsMet(ctx context.Context, t *taskfile.Task
 			Env:     env.Get(t),
 		})
 		if err != nil {
-			e.Logger.Errf(logger.Magenta, "task: %s\n", p.Msg)
+			if !errors.Is(err, context.Canceled) {
+				e.Logger.Errf(logger.Magenta, "task: %s\n", p.Msg)
+			}
 			return false, ErrPreconditionFailed
 		}
 	}
