@@ -1,13 +1,11 @@
 package task
 
 import (
-	"bufio"
 	"context"
 	"fmt"
 	"io"
 	"os"
 	"runtime"
-	"strings"
 	"sync"
 	"sync/atomic"
 	"time"
@@ -23,7 +21,6 @@ import (
 	"github.com/go-task/task/v3/internal/sort"
 	"github.com/go-task/task/v3/internal/summary"
 	"github.com/go-task/task/v3/internal/templater"
-	"github.com/go-task/task/v3/internal/term"
 	"github.com/go-task/task/v3/taskfile"
 
 	"github.com/sajari/fuzzy"
@@ -34,14 +31,9 @@ import (
 const (
 	// MaximumTaskCall is the max number of times a task can be called.
 	// This exists to prevent infinite loops on cyclic dependencies
-	MaximumTaskCall = 100
+	MaximumTaskCall = 1000
 )
 
-func shouldPromptContinue(input string) bool {
-	input = strings.ToLower(strings.TrimSpace(input))
-	return slices.Contains([]string{"y", "yes"}, input)
-}
-
 // Executor executes a Taskfile
 type Executor struct {
 	Taskfile *taskfile.Taskfile
@@ -58,13 +50,13 @@ type Executor struct {
 	Verbose     bool
 	Silent      bool
 	AssumeYes   bool
+	AssumeTerm  bool // Used for testing
 	Dry         bool
 	Summary     bool
 	Parallel    bool
 	Color       bool
 	Concurrency int
 	Interval    time.Duration
-	AssumesTerm bool
 
 	Stdin  io.Reader
 	Stdout io.Writer
@@ -123,12 +115,13 @@ func (e *Executor) Run(ctx context.Context, calls ...taskfile.Call) error {
 		return nil
 	}
 
-	if e.Watch {
-		return e.watchTasks(calls...)
+	regularCalls, watchCalls, err := e.splitRegularAndWatchCalls(calls...)
+	if err != nil {
+		return err
 	}
 
 	g, ctx := errgroup.WithContext(ctx)
-	for _, c := range calls {
+	for _, c := range regularCalls {
 		c := c
 		if e.Parallel {
 			g.Go(func() error { return e.RunTask(ctx, c) })
@@ -138,7 +131,31 @@ func (e *Executor) Run(ctx context.Context, calls ...taskfile.Call) error {
 			}
 		}
 	}
-	return g.Wait()
+	if err := g.Wait(); err != nil {
+		return err
+	}
+
+	if len(watchCalls) > 0 {
+		return e.watchTasks(watchCalls...)
+	}
+
+	return nil
+}
+
+func (e *Executor) splitRegularAndWatchCalls(calls ...taskfile.Call) (regularCalls []taskfile.Call, watchCalls []taskfile.Call, err error) {
+	for _, c := range calls {
+		t, err := e.GetTask(c)
+		if err != nil {
+			return nil, nil, err
+		}
+
+		if e.Watch || t.Watch {
+			watchCalls = append(watchCalls, c)
+		} else {
+			regularCalls = append(regularCalls, c)
+		}
+	}
+	return
 }
 
 // RunTask runs a task by its name
@@ -148,28 +165,22 @@ func (e *Executor) RunTask(ctx context.Context, call taskfile.Call) error {
 		return err
 	}
 	if !e.Watch && atomic.AddInt32(e.taskCallCount[t.Task], 1) >= MaximumTaskCall {
-		return &errors.TaskCalledTooManyTimesError{TaskName: t.Task}
+		return &errors.TaskCalledTooManyTimesError{
+			TaskName:        t.Task,
+			MaximumTaskCall: MaximumTaskCall,
+		}
 	}
 
 	release := e.acquireConcurrencyLimit()
 	defer release()
 
-	if t.Prompt != "" && !e.AssumeYes {
-		if !e.AssumesTerm && !term.IsTerminal() {
+	if t.Prompt != "" {
+		if err := e.Logger.Prompt(logger.Yellow, t.Prompt, "n", "y", "yes"); errors.Is(err, logger.ErrNoTerminal) {
 			return &errors.TaskCancelledNoTerminalError{TaskName: call.Task}
-		}
-
-		e.Logger.Outf(logger.Yellow, "task: %q [y/N]: ", t.Prompt)
-
-		reader := bufio.NewReader(e.Stdin)
-		userInput, err := reader.ReadString('\n')
-		if err != nil {
-			return err
-		}
-
-		userInput = strings.ToLower(strings.TrimSpace(userInput))
-		if !shouldPromptContinue(userInput) {
+		} else if errors.Is(err, logger.ErrPromptCancelled) {
 			return &errors.TaskCancelledByUserError{TaskName: call.Task}
+		} else if err != nil {
+			return err
 		}
 	}
 
@@ -458,13 +469,14 @@ func (e *Executor) GetTaskList(filters ...FilterFunc) ([]*taskfile.Task, error)
 
 	// Compile the list of tasks
 	for i := range tasks {
-		task := tasks[i]
+		idx := i
+		task := tasks[idx]
 		g.Go(func() error {
 			compiledTask, err := e.FastCompiledTask(taskfile.Call{Task: task.Task})
 			if err == nil {
 				task = compiledTask
 			}
-			task = compiledTask
+			tasks[idx] = compiledTask
 			return nil
 		})
 	}
