@@ -41,10 +41,14 @@ func readTaskfile(
 	l *logger.Logger,
 ) (*taskfile.Taskfile, error) {
 	var b []byte
+	var err error
+	var cache *Cache
 
-	cache, err := NewCache(tempDir)
-	if err != nil {
-		return nil, err
+	if node.Remote() {
+		cache, err = NewCache(tempDir)
+		if err != nil {
+			return nil, err
+		}
 	}
 
 	// If the file is remote, check if we have a cached copy
@@ -82,19 +86,19 @@ func readTaskfile(
 			checksum := checksum(b)
 			cachedChecksum := cache.readChecksum(node)
 
-			// If the checksum doesn't exist, prompt the user to continue
+			var msg string
 			if cachedChecksum == "" {
-				if cont, err := l.Prompt(logger.Yellow, fmt.Sprintf("The task you are attempting to run depends on the remote Taskfile at %q.\n--- Make sure you trust the source of this Taskfile before continuing ---\nContinue?", node.Location()), "n", "y", "yes"); err != nil {
-					return nil, err
-				} else if !cont {
-					return nil, &errors.TaskfileNotTrustedError{URI: node.Location()}
-				}
+				// If the checksum doesn't exist, prompt the user to continue
+				msg = fmt.Sprintf("The task you are attempting to run depends on the remote Taskfile at %q.\n--- Make sure you trust the source of this Taskfile before continuing ---\nContinue?", node.Location())
 			} else if checksum != cachedChecksum {
 				// If there is a cached hash, but it doesn't match the expected hash, prompt the user to continue
-				if cont, err := l.Prompt(logger.Yellow, fmt.Sprintf("The Taskfile at %q has changed since you last used it!\n--- Make sure you trust the source of this Taskfile before continuing ---\nContinue?", node.Location()), "n", "y", "yes"); err != nil {
-					return nil, err
-				} else if !cont {
+				msg = fmt.Sprintf("The Taskfile at %q has changed since you last used it!\n--- Make sure you trust the source of this Taskfile before continuing ---\nContinue?", node.Location())
+			}
+			if msg != "" {
+				if err := l.Prompt(logger.Yellow, msg, "n", "y", "yes"); errors.Is(err, logger.ErrPromptCancelled) {
 					return nil, &errors.TaskfileNotTrustedError{URI: node.Location()}
+				} else if err != nil {
+					return nil, err
 				}
 			}
 
@@ -143,6 +147,11 @@ func Taskfile(
 			return nil, err
 		}
 
+		// Check that the Taskfile is set and has a schema version
+		if t == nil || t.Version == nil {
+			return nil, &errors.TaskfileVersionNotDefined{URI: node.Location()}
+		}
+
 		// Annotate any included Taskfile reference with a base directory for resolving relative paths
 		if node, isFileNode := node.(*FileNode); isFileNode {
 			_ = t.Includes.Range(func(key string, includedFile taskfile.IncludedTaskfile) error {
@@ -296,43 +305,43 @@ func Taskfile(
 	return _taskfile(node)
 }
 
-// exists will check if a file at the given path exists. If it does, it will
+// Exists will check if a file at the given path Exists. If it does, it will
 // return the path to it. If it does not, it will search the search for any
 // files at the given path with any of the default Taskfile files names. If any
 // of these match a file, the first matching path will be returned. If no files
 // are found, an error will be returned.
-func exists(path string) (string, error) {
+func Exists(path string) (string, error) {
 	fi, err := os.Stat(path)
 	if err != nil {
 		return "", err
 	}
 	if fi.Mode().IsRegular() {
-		return path, nil
+		return filepath.Abs(path)
 	}
 
 	for _, n := range defaultTaskfiles {
 		fpath := filepathext.SmartJoin(path, n)
 		if _, err := os.Stat(fpath); err == nil {
-			return fpath, nil
+			return filepath.Abs(fpath)
 		}
 	}
 
 	return "", errors.TaskfileNotFoundError{URI: path, Walk: false}
 }
 
-// existsWalk will check if a file at the given path exists by calling the
+// ExistsWalk will check if a file at the given path exists by calling the
 // exists function. If a file is not found, it will walk up the directory tree
 // calling the exists function until it finds a file or reaches the root
 // directory. On supported operating systems, it will also check if the user ID
 // of the directory changes and abort if it does.
-func existsWalk(path string) (string, error) {
+func ExistsWalk(path string) (string, error) {
 	origPath := path
 	owner, err := sysinfo.Owner(path)
 	if err != nil {
 		return "", err
 	}
 	for {
-		fpath, err := exists(path)
+		fpath, err := Exists(path)
 		if err == nil {
 			return fpath, nil
 		}
